@@ -1,8 +1,12 @@
-# Copyright (c) 2016-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2016, 2019 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2016-2018 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
 # Copyright (c) 2016 Glenn Matthews <glenn@e-dad.net>
-# Copyright (c) 2016 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2018 Jim Robertson <jrobertson98atx@gmail.com>
 # Copyright (c) 2018 Adam Dangoor <adamdangoor@gmail.com>
+# Copyright (c) 2019-2020 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
+# Copyright (c) 2019 Danny Hermes <daniel.j.hermes@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -10,6 +14,9 @@
 """Unit tests for the raised exception documentation checking in the
 `DocstringChecker` in :mod:`pylint.extensions.check_docs`
 """
+
+# pylint: disable=too-many-public-methods
+
 import astroid
 
 from pylint.extensions.docparams import DocstringParameterChecker
@@ -110,7 +117,6 @@ class TestDocstringCheckerRaise(CheckerTestCase):
         )
         with self.assertNoMessages():
             self.checker.visit_raise(raise_node)
-        pass
 
     def test_find_google_attr_raises_substr_exc(self):
         raise_node = astroid.extract_node(
@@ -295,6 +301,43 @@ class TestDocstringCheckerRaise(CheckerTestCase):
         with self.assertNoMessages():
             self.checker.visit_raise(raise_node)
 
+    def test_find_multiple_sphinx_raises(self):
+        raise_node = astroid.extract_node(
+            '''
+        def my_func(self):
+            """This is a docstring.
+
+            :raises RuntimeError: Always
+            :raises NameError, OSError, ValueError: Never
+            """
+            raise RuntimeError('hi')
+            raise NameError('hi') #@
+            raise OSError(2, 'abort!')
+            raise ValueError('foo')
+        '''
+        )
+        with self.assertNoMessages():
+            self.checker.visit_raise(raise_node)
+
+    def test_find_multiple_google_raises(self):
+        raise_node = astroid.extract_node(
+            '''
+        def my_func(self):
+            """This is a docstring.
+
+            Raises:
+                RuntimeError: Always
+                NameError, OSError, ValueError: Never
+            """
+            raise RuntimeError('hi')
+            raise NameError('hi') #@
+            raise OSError(2, 'abort!')
+            raise ValueError('foo')
+        '''
+        )
+        with self.assertNoMessages():
+            self.checker.visit_raise(raise_node)
+
     def test_finds_rethrown_sphinx_raises(self):
         raise_node = astroid.extract_node(
             '''
@@ -525,7 +568,6 @@ class TestDocstringCheckerRaise(CheckerTestCase):
         )
         with self.assertNoMessages():
             self.checker.visit_raise(raise_node)
-        pass
 
     def test_find_numpy_attr_raises_substr_exc(self):
         raise_node = astroid.extract_node(
