@@ -1,5 +1,5 @@
 """Check trailing comma one element tuples."""
-# pylint: disable=bad-whitespace, missing-docstring
+# pylint: disable=bad-whitespace, missing-docstring, bad-continuation
 AAA = 1, # [trailing-comma-tuple]
 BBB = "aaaa", # [trailing-comma-tuple]
 CCC="aaa", # [trailing-comma-tuple]
@@ -36,3 +36,15 @@ def some_func(first, second):
 
 def some_other_func():
     yield 'hello',  # [trailing-comma-tuple]
+
+GGG = ["aaa"
+], # [trailing-comma-tuple]
+
+HHH = ["aaa"
+]
+
+III = some_func(0,
+    0), # [trailing-comma-tuple]
+
+JJJ = some_func(0,
+    0)
