@@ -2,7 +2,7 @@
 # Copyright (c) 2009-2011, 2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
 # Copyright (c) 2012 FELD Boris <lothiraldan@gmail.com>
 # Copyright (c) 2013-2014 Google, Inc.
-# Copyright (c) 2014-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014-2019 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2014 buck <buck.2019@gmail.com>
 # Copyright (c) 2014 Arun Persaud <arun@nubati.net>
 # Copyright (c) 2015 Harut <yes@harutune.name>
@@ -13,9 +13,12 @@
 # Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
 # Copyright (c) 2017 James M. Allen <james.m.allen@gmail.com>
 # Copyright (c) 2017 vinnyrose <vinnyrose@users.noreply.github.com>
+# Copyright (c) 2018, 2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2018 Bryce Guinta <bryce.guinta@protonmail.com>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2018 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2019-2020 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
+# Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -29,7 +32,7 @@ import tokenize
 import astroid
 
 from pylint import lint, reporters
-from pylint.checkers.format import *
+from pylint.checkers.format import FormatChecker
 from pylint.testutils import CheckerTestCase, Message, _tokenize_str, set_config
 
 
@@ -112,6 +115,23 @@ class TestMultiStatementLine(CheckerTestCase):
         self.checker.process_tokens([])
         self.checker.visit_default(tree.body[0])
 
+    def test_ellipsis_is_ignored(self):
+        code = """
+        from typing import overload
+        @overload
+        def concat2(arg1: str) -> str: ...
+        """
+        tree = astroid.extract_node(code)
+        with self.assertNoMessages():
+            self.visitFirst(tree)
+
+        code = """
+        def concat2(arg1: str) -> str: ...
+        """
+        stmt = astroid.extract_node(code)
+        with self.assertAddsMessages(Message("multiple-statements", node=stmt.body[0])):
+            self.visitFirst(stmt)
+
 
 class TestSuperfluousParentheses(CheckerTestCase):
     CHECKER_CLASS = FormatChecker
@@ -401,7 +421,7 @@ class TestCheckSpace(CheckerTestCase):
             )
 
     def testOperatorSpacingGood(self):
-        good_cases = ["a = b\n" "a < b\n" "a\n< b\n"]
+        good_cases = ["a = b\n", "a < b\n", "a\n< b\n"]
         with self.assertNoMessages():
             for code in good_cases:
                 self.checker.process_tokens(_tokenize_str(code))
